<p>To begin, tell IceBear where to keep uploaded files, images imported from imagers, etc.</p>
<p>The pre-installation script created and configured <strong>/icebearstore</strong> for you, but you can specify another location. This directory must exist and be writable by the Apache user (typically www-root).</p>
<label>Path to storage: <input name="livestore" type="text" value="/icebearstore"/></label>
<p>IceBear will back up its database nightly if you specify a backup directory. Imported images and uploaded files will also be backed up into this directory as they are added to IceBear.</p>
<p>If you specify a backup directory, it must exist and be writable by the Apache user (typically www-root); you must also specify how many nightly backups you wish to keep.</p>
<label>Path to backups: <input type="text" name="backupstore" value="" /></label>
<label>Number of database backups to keep: <input type="text" name="backupstokeep" value="" /></label>
<p>It is <strong>strongly recommended</strong> that you back up the database, uploaded files, and imported images! If you don't use the IceBear mechanism, you should have another backup system in place.</p>
<p>Your backups should at least be on a different disk from your working storage! Put backups as far from your IceBear server as is practical.</p>

